@@ -15,7 +15,7 @@
 
 #include <telepathy-glib/debug.h>
 
-#include <tests/lib/contactlist/conn.h>
+#include <tests/lib/glib/contactlist/conn.h>
 #include <tests/lib/test.h>
 
 using namespace Tp;
@@ -33,6 +33,7 @@ protected Q_SLOTS:
     void expectConnInvalidated();
     void expectPendingContactsFinished(Tp::PendingOperation *);
     void expectPresenceStateChanged(Tp::Contact::PresenceState);
+    void expectAllKnownContactsChanged(const Tp::Contacts &added, const Tp::Contacts &removed);
 
 private Q_SLOTS:
     void initTestCase();
@@ -48,6 +49,7 @@ private:
     ExampleContactListConnection *mConnService;
     ConnectionPtr mConn;
     QList<ContactPtr> mContacts;
+    int mHowManyKnownContacts;
 };
 
 void TestConnRoster::expectConnInvalidated()
@@ -83,6 +85,20 @@ void TestConnRoster::expectPendingContactsFinished(PendingOperation *op)
     mLoop->exit(0);
 }
 
+void TestConnRoster::expectAllKnownContactsChanged(const Tp::Contacts& added, const Tp::Contacts& removed)
+{
+    qDebug() << added.size() << " contacts added, " << removed.size() << " contacts removed";
+    mHowManyKnownContacts += added.size();
+    mHowManyKnownContacts -= removed.size();
+    if (mConn->contactManager()->allKnownContacts().size() != mHowManyKnownContacts) {
+        qWarning() << "Contacts number mismatch! Watched value: " << mHowManyKnownContacts
+                   << "allKnownContacts(): " << mConn->contactManager()->allKnownContacts().size();
+        mLoop->exit(1);
+    } else {
+        mLoop->exit(0);
+    }
+}
+
 void TestConnRoster::expectPresenceStateChanged(Contact::PresenceState state)
 {
     mLoop->exit(0);
@@ -114,8 +130,8 @@ void TestConnRoster::initTestCase()
     QVERIFY(name != 0);
     QVERIFY(connPath != 0);
 
-    mConnName = name;
-    mConnPath = connPath;
+    mConnName = QLatin1String(name);
+    mConnPath = QLatin1String(connPath);
 
     g_free(name);
     g_free(connPath);
@@ -146,14 +162,14 @@ void TestConnRoster::testRoster()
     QCOMPARE(mConn->isReady(features), true);
 
     QStringList toCheck = QStringList() <<
-        "sjoerd@example.com" <<
-        "travis@example.com" <<
-        "wim@example.com" <<
-        "olivier@example.com" <<
-        "helen@example.com" <<
-        "geraldine@example.com" <<
-        "guillaume@example.com" <<
-        "christian@example.com";
+        QLatin1String("sjoerd@example.com") <<
+        QLatin1String("travis@example.com") <<
+        QLatin1String("wim@example.com") <<
+        QLatin1String("olivier@example.com") <<
+        QLatin1String("helen@example.com") <<
+        QLatin1String("geraldine@example.com") <<
+        QLatin1String("guillaume@example.com") <<
+        QLatin1String("christian@example.com");
     QStringList ids;
     QList<ContactPtr> pendingSubscription;
     QList<ContactPtr> pendingPublish;
@@ -176,13 +192,15 @@ void TestConnRoster::testRoster()
     QCOMPARE(pendingPublish.size(), 2);
 
     // Wait for the contacts to be built
-    ids = QStringList() << QString("john@example.com") << QString("mary@example.com");
+    ids = QStringList() << QString(QLatin1String("john@example.com"))
+        << QString(QLatin1String("mary@example.com"));
     QVERIFY(connect(mConn->contactManager()->contactsForIdentifiers(ids),
                     SIGNAL(finished(Tp::PendingOperation*)),
                     SLOT(expectPendingContactsFinished(Tp::PendingOperation*))));
     QCOMPARE(mLoop->exec(), 0);
 
     int i = 0;
+
     foreach (const ContactPtr &contact, mContacts) {
         QVERIFY(connect(contact.data(),
                         SIGNAL(subscriptionStateChanged(Tp::Contact::PresenceState)),
@@ -191,9 +209,9 @@ void TestConnRoster::testRoster()
                         SIGNAL(publishStateChanged(Tp::Contact::PresenceState)),
                         SLOT(expectPresenceStateChanged(Tp::Contact::PresenceState))));
         if ((i % 2) == 0) {
-            contact->requestPresenceSubscription("please add me");
+            contact->requestPresenceSubscription(QLatin1String("please add me"));
         } else {
-            contact->requestPresenceSubscription("add me now");
+            contact->requestPresenceSubscription(QLatin1String("add me now"));
         }
 
         QCOMPARE(mLoop->exec(), 0);
@@ -251,6 +269,30 @@ void TestConnRoster::testRoster()
 
         ++i;
     }
+
+    // Test allKnownContactsChanged.
+    // In this test, everytime a subscription is requested or rejected, allKnownContacts changes
+    // Cache the current value
+    mHowManyKnownContacts = mConn->contactManager()->allKnownContacts().size();
+    // Watch for contacts changed
+    QVERIFY(connect(mConn->contactManager(),
+                    SIGNAL(allKnownContactsChanged(Tp::Contacts,Tp::Contacts)),
+                    SLOT(expectAllKnownContactsChanged(Tp::Contacts,Tp::Contacts))));
+
+    // Wait for the contacts to be built
+    ids = QStringList() << QString(QLatin1String("kctest1@example.com"))
+        << QString(QLatin1String("kctest2@example.com"));
+    QVERIFY(connect(mConn->contactManager()->contactsForIdentifiers(ids),
+                    SIGNAL(finished(Tp::PendingOperation*)),
+                    SLOT(expectPendingContactsFinished(Tp::PendingOperation*))));
+    QCOMPARE(mLoop->exec(), 0);
+
+    foreach (const ContactPtr &contact, mContacts) {
+        contact->requestPresenceSubscription(QLatin1String("add me now"));
+
+        // allKnownContacts is supposed to change here.
+        QCOMPARE(mLoop->exec(), 0);
+    }
 }
 
 void TestConnRoster::cleanup()
